import React, { useEffect, useMemo, useRef } from 'react'
import Taro from '@tarojs/taro'
import { View, Canvas } from '@tarojs/components'
import CodeText from './CodeText'
import { code128 } from './drawCode'
import './style.less'

export default (props) => {

  const { width, height, code } = props

  const canvasRef = useRef()
  const ctxRef = useRef()

  console.log('---------------->', Taro.getSystemInfoSync().pixelRatio)

  const dpr = useMemo(() => Taro.getSystemInfoSync().pixelRatio, [])
  const size = useMemo(() => ({ width: width * dpr, height: height * dpr }), [width, height, dpr])

  const style = useMemo(() => ({ width: `${size.width}rpx`, height: `${size.height}rpx` }), [size])

  useEffect(() => {
    Taro.nextTick(() => {
      const query = Taro.createSelectorQuery()
      query.select('#barCodeCanvas').fields({ node: true }).exec((res) => {
        const canvas = res[0].node
        const ctx = canvas.getContext('2d')
        canvas.width = size.width
        canvas.height = size.height
        ctx.scale(dpr, dpr)

        canvasRef.current = canvas;
        ctxRef.current = ctx;

        if (code) {
          code128(ctx, code, size.width, size.height);
        }
      })
    })
  }, [code, size, dpr])

  return (
    <View className='barcode-box' style={style}>
      <Canvas style={style} type='2d' id='barCodeCanvas'></Canvas>
      <CodeText code={code}/>
    </View>
  )
}
